==> kleopatra-16.04.1.tar.xz: kleopatra-16.04.1/src/commands/gnupgprocesscommand.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    commands/gnupgprocesscommand.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_COMMMANDS_GNUPGPROCESSCOMMAND_H__
#define __KLEOPATRA_COMMMANDS_GNUPGPROCESSCOMMAND_H__

#include <commands/command.h>

class QStringList;
class QString;

namespace Kleo
{
namespace Commands
{

class GnuPGProcessCommand : public Command
{
    Q_OBJECT
protected:
    explicit GnuPGProcessCommand(QAbstractItemView *view, KeyListController *parent);
    explicit GnuPGProcessCommand(KeyListController *parent);
    explicit GnuPGProcessCommand(const GpgME::Key &key);
    ~GnuPGProcessCommand();

public:
    QDialog *dialog() const;

private:
    virtual bool preStartHook(QWidget *parentWidget) const;

    virtual QStringList arguments() const = 0;

    virtual QString errorCaption() const = 0;
    virtual QString successCaption() const = 0;

    virtual QString crashExitMessage(const QStringList &args) const = 0;
    virtual QString errorExitMessage(const QStringList &args) const = 0;
    virtual QString successMessage(const QStringList &args) const = 0;

    virtual void postSuccessHook(QWidget *parentWidget);

protected:
    QString errorString() const;
    void setIgnoresSuccessOrFailure(bool ignore);
    bool ignoresSuccessOrFailure() const;
    void setShowsOutputWindow(bool show);
    bool showsOutputWindow() const;

private:
    void doStart() Q_DECL_OVERRIDE;
    void doCancel() Q_DECL_OVERRIDE;

private:
    class Private;
    inline Private *d_func();
    inline const Private *d_func() const;
    Q_PRIVATE_SLOT(d_func(), void slotProcessFinished(int, QProcess::ExitStatus))
    Q_PRIVATE_SLOT(d_func(), void slotProcessReadyReadStandardError())
};

}
}

#endif // __KLEOPATRA_COMMMANDS_GNUPGPROCESSCOMMAND_H__

==> kleopatra-16.08.1.tar.xz: kleopatra-16.08.1/src/commands/gnupgprocesscommand.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    commands/gnupgprocesscommand.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_COMMMANDS_GNUPGPROCESSCOMMAND_H__
#define __KLEOPATRA_COMMMANDS_GNUPGPROCESSCOMMAND_H__

#include <commands/command.h>

class QStringList;
class QString;
class QProcess;

namespace Kleo
{
namespace Commands
{

class GnuPGProcessCommand : public Command
{
    Q_OBJECT
protected:
    explicit GnuPGProcessCommand(QAbstractItemView *view, KeyListController *parent);
    explicit GnuPGProcessCommand(KeyListController *parent);
    explicit GnuPGProcessCommand(const GpgME::Key &key);
    ~GnuPGProcessCommand();

public:
    QDialog *dialog() const;

private:
    virtual bool preStartHook(QWidget *parentWidget) const;

    virtual QStringList arguments() const = 0;

    virtual QString errorCaption() const = 0;
    virtual QString successCaption() const;

    virtual QString crashExitMessage(const QStringList &args) const = 0;
    virtual QString errorExitMessage(const QStringList &args) const = 0;
    virtual QString successMessage(const QStringList &args) const;

    virtual void postSuccessHook(QWidget *parentWidget);

protected:
    QString errorString() const;
    void setIgnoresSuccessOrFailure(bool ignore);
    bool ignoresSuccessOrFailure() const;
    void setShowsOutputWindow(bool show);
    bool showsOutputWindow() const;

    QProcess *process();

private:
    void doStart() Q_DECL_OVERRIDE;
    void doCancel() Q_DECL_OVERRIDE;

private:
    class Private;
    inline Private *d_func();
    inline const Private *d_func() const;
    Q_PRIVATE_SLOT(d_func(), void slotProcessFinished(int, QProcess::ExitStatus))
    Q_PRIVATE_SLOT(d_func(), void slotProcessReadyReadStandardError())
};

}
}

#endif // __KLEOPATRA_COMMMANDS_GNUPGPROCESSCOMMAND_H__
